# MangoWG
Mango Website Generator PyPi Package 

## Python Venv

* `python -m venv venv`
* `venv\Scripts\activate.bat`
* `pip install -r requirements.txt`
* `pip freeze > requirements.txt`

## PyPi publish 

* install poetry
* `poetry init`
* `poetry build`
* `poetry publish -u USERNAME -p PASSWORD`
    * use pypi password for this step